@@ -1,6 +1,6 @@
 package Transform::Alert;
 
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '1.00'; # VERSION
 # ABSTRACT: Transform alerts from one type to another type
 
 use sanity 0.94;
@@ -56,33 +56,33 @@ around BUILDARGS => sub {
 
    my $conf    = $hash->{config};
    my $basedir = $hash->{basedir} = $conf->{basedir};
-   
+
    chdir $basedir;  # just go there to make relative pathing easier
 
    # process outputs first (needed for Template sets)
    $hash->{outputs} = {};
    foreach my $out_key (keys %{ $conf->{output} }) {
       my $out_conf  = dclone $conf->{output}{$out_key};
-      
+
       # create the new class
       my $type = delete $out_conf->{type} || die "Output '$out_key' requires a Type!";
       my $class = "Transform::Alert::Output::$type";
       load_class $class;
       $hash->{outputs}{$out_key} = $class->new($out_conf);
    }
-   
+
    # now process inputs
    $hash->{inputs} = {};
    foreach my $in_key (keys %{ $conf->{input} }) {
       my $in_conf  = dclone $conf->{input}{$in_key};
-      
+
       $in_conf->{name}        = $in_key;
       $in_conf->{output_objs} = $hash->{outputs};
-      
+
       # create the input group
       $hash->{inputs}{$in_key} = Transform::Alert::InputGrp->new($in_conf);
    }
-   
+
    $orig->($self, $hash);
 };
 
@@ -95,7 +95,7 @@ sub BUILD {
 sub heartbeat {
    my $self = shift;
    my $log  = $self->log;
-   
+
    $log->debug('START Heartbeat');
    foreach my $in_key (sort {
       # sorting these by time_left, so that (hopefully) as much as possible is processed in one heartbeat
@@ -103,14 +103,14 @@ sub heartbeat {
    } keys %{ $self->inputs }) {
       $log->debug('Looking at Input "'.$in_key.'"...');
       my $in = $self->inputs->{$in_key};
-   
+
       # are we ready for another run?
       if (time > $in->last_finished + $in->interval) {
          $in->process;
       }
    }
    $log->debug('END Heartbeat');
-   
+
    # shut up until I'm ready...
    return min map { $_->time_left } values %{ $self->inputs };
 }
@@ -121,7 +121,7 @@ sub close_all {
    $log->debug('Closing all I/O for ALL groups');
 
    $_->close_all for (values %{ $self->inputs });
-   
+
    return 1;
 }
 
@@ -164,7 +164,7 @@ Transform::Alert - Transform alerts from one type to another type
           TemplateFile  test_in/server01_email.re
           Munger        test_in/Munger.pm MyMunger->munge
           OutputName    test_out
-       </Template>         
+       </Template>
     </Input>
     <Output test_out>
        Type          Syslog
@@ -222,12 +222,12 @@ Or to show it with a UTF8 drawing, the platform works like this:
             ├── InTemplate + Munger ──┬── Output + OutTemplate
             │                         └── Output + OutTemplate
             ├── InTemplate + Munger ──┬── Output + OutTemplate
-            └── InTemplate ───────────┘ 
+            └── InTemplate ───────────┘
     Input ──┬── InTemplate ────────────── Output + OutTemplate
             └── InTemplate + Munger ───── Output + OutTemplate
 
 All L<inputs|Transform::Alert::Input> and L<outputs|Transform::Alert::Output> are separate modules, so if there isn't a protocol available, they
-are easy to make.  Input templates use a multi-line regular expression with named captures to categorize the variables.  Output templates are 
+are easy to make.  Input templates use a multi-line regular expression with named captures to categorize the variables.  Output templates are
 L<TT|Template::Toolkit> templates with a C<<< [% var %] >>> syntax.  If you need to transform the data after it's been captured, you can use a "munger"
 module to play with the variables any way you see fit.
 
@@ -263,7 +263,7 @@ The C<<< Type >>> specifies the type of input used.  This maps to a C<<< Transfo
 be found with the corresponding documentation.
 
 The C<<< Interval >>> specifies how frequently the input should be checked (in seconds).  Server-based input shouldn't be checked too often, as it
-might be considered abusive.  In the case of overruns, the input will only be re-checked after the interval is complete.  (In other words, the
+might be considered abusive.  To prevent overruns, the input will only be re-checked after the interval is complete.  (In other words, the
 "last finished" time is recorded, not the "last start".)
 
 There is one C<<< ConnOpts >>> section in each input.  The options will be specific to each type, so look there for documentation.
@@ -280,20 +280,21 @@ The engine may someday be changed to have multi-processed inputs, but the need i
  
           Munger        [file] [class]->[method]  # optional
           OutputName    test_out    # one or more
-       </Template>         
+       </Template>
     </Input>
 
-All C<<< Input >>> sections must have one or more C<<< Template >>> sections.  (In this case, this is an input template.)  As messages are being processed,
-each message is tested on all of the templates.
+All C<<< Input >>> sections must have one or more C<<< Template >>> sections.  As messages are being processed, each message is tested on all of the
+templates.  Input messages will be ran through B<all> templates tied to that input, even if that message matched a previous template.  To prevent
+a message from matching multiple templates, make sure they are reasonably unique.
 
 All templates must either have a C<<< TemplateFile >>> or C<<< Template >>> option.  In most cases, you should stick with file-based templates, as inline
 templates are whitespace sensitive, and should only be used for single line REs.
 
 If you don't set a Template option, a template file is not used.  Without a Munger to validate the hash, these templates will be accepted (and
-sent to the output), as long as it passes data.
+sent to the outputs), as long as it passes data.
 
 The optional C<<< Munger >>> option can be used to specify a module used in changing the variables between the input and output.  (More details about
-Mungers further down.)  The option itself can be expressed in a number of ways:
+L<Mungers further down|/Mungers>.)  The option itself can be expressed in a number of ways:
 
     Munger  File.pm
     Munger  File.pm->method
@@ -306,7 +307,9 @@ If a class isn't specified, the first package name found in the file is used.  I
 isn't a file specified, it will try to load the class like C<<< use/require >>>.  (Technically, you could take advantage of the C<<< . >>> path in C<<< %INC >>>,
 but it's better to just provide the filename.)
 
-If both a C<<< Template >>>E<sol>{TemplateFile} & C<<< Munger >>> option are passed, it will test both forms as an AND-based match, testing the text form first.
+If both C<<< Template/File >>> & C<<< Munger >>> options are passed, it will test both forms as an AND-based match, testing the text form via template
+first.  This has the benefit of using the input templates as a "gatekeeper", and can be used to delegate different templates to different
+Mungers.  Any named captures from the input template will be passed as a C<<< t >>> hash in the variables to the Munger.
 
 The C<<< OutputName >>> options provide the name of the Output sources to use after a template match is found.  (These sources are defined below.)
 More that one option means that the alert will be sent to multiple sources.
@@ -324,7 +327,7 @@ More that one option means that the alert will be sent to multiple sources.
 Like C<<< Input >>>, C<<< Output >>> sections need to be uniquely named.  This name is used with the C<<< OutputName >>> option above.  Also like C<<< Input >>>, the
 C<<< Type >>> functions the same way (mapping to a C<<< Transform::Alert::Output::* >>> class), and C<<< ConnOpts >>> contains all of the module-specific options.
 
-Similar to C<<< Template >>> sections, the C<<< Output >>> section must either have a C<<< TemplateFile >>> or a C<<< Template >>> option.  However, you can only use a 
+Similar to C<<< Template >>> sections, the C<<< Output >>> section must either have a C<<< TemplateFile >>> or a C<<< Template >>> option.  However, you can only use a
 single template per C<<< Output >>>.  If you need more, use another section with most of the same options.
 
 =head2 Directory Structure
@@ -332,20 +335,21 @@ single template per C<<< Output >>>.  If you need more, use another section with
 Depending on how large your setup is, you may want to create a directory structure like this:
 
     /opt/transalert          # config, log, PID
-    /opt/transalert/input1   # various input template directories                 
-    /opt/transalert/input2   
+    /opt/transalert/input1   # various input template directories
+    /opt/transalert/input2
     /opt/transalert/input3
     /opt/transalert/outputs  # single directory for output templates
 
-If your set up is small, you can get away with a single directory.  Just be sure to use the logE<sol>PID options in L<transalert_ctl>, so that they
-are put in the right directory.
+If your set up is small, you can get away with a single directory, or at least single inputE<sol>output directories.  Just be sure to use the logE<sol>PID
+options in L<transalert_ctl>, so that they are put in the right directory.
 
 =head2 Input Templates
 
 Input templates are basically big multi-line regular expressions.  These are NOT C<<< /x >>> whitespace-insensitive regular expressions, as those
 would make copyE<sol>pasting large bodies of text more difficult.  (There's an assumption that most input templates will have more static text than
-freeform RE parts.)  Besides, you can still use a C<<< (?x...) >>> construct.  Also, leading and trailing whitespace is removed, so stray whitespace
-should not be an issue there.  RE templates are also put into a C<<< ^$re$ >>>, with beginE<sol>end symbols, which can easily be overriden with C<<< .* >>>.
+freeform RE parts.)  Besides, you can still use a C<<< (?x...) >>> construct for whitespace-insensitivity and comments.  Also, leading and trailing
+whitespace is removed, so stray whitespace should not be an issue there.  RE templates are also put into a C<<< ^$re$ >>>, with beginE<sol>end symbols,
+which can easily be overriden with C<<< .* >>>.
 
 Please note that a matched template doesn't stop the matching process, so make sure the templates are unique enough if you don't want to
 match multiple templates.
@@ -371,7 +375,7 @@ of L<Mungers|/Mungers>.
 
 =head2 Output Templates
 
-Output templates use L<Template::Toolkit>.  If you want a quick and dirty lesson on how they work, check out L<Template::Manual::Syntax>.  If 
+Output templates use L<Template::Toolkit>.  If you want a quick and dirty lesson on how they work, check out L<Template::Manual::Syntax>.  If
 B<that> is too wordy for you, then just remember that variables are replaced with a C<<< [% t.var %] >>> syntax.
 
 The variables passed to the Output (or Munger, if specified) will look like this:
@@ -385,7 +389,8 @@ The variables passed to the Output (or Munger, if specified) will look like this
        }
     }
 
-For a structure of the C<<< p >>> hash passed, look at the documentation for that input module.
+For a structure of the C<<< p >>> hash passed, look at the documentation for that input module (under C<<< Preparsed Hash >>>).  Note that Munger mangling
+could totally change the structure of the hash passed to the Outputs, depending on what it returns.
 
 Here's an example output template that looks similar to the input one above:
 
@@ -403,7 +408,7 @@ Here's an example output template that looks similar to the input one above:
 =head2 Mungers
 
 Mungers are an optional second piece to the input template structure.  Regular expressions, as powerful as they are with finding and capturing
-information, only do just that.  Sometimes you need to warp the information you've captured to fit the mold that the output can use.  Or 
+information, only do just that.  Sometimes you need to warp the information you've captured to fit the mold that the output can use.  Or
 sometimes you need to validate the input in a better fashion than REs can provide.  Mungers fit both of those roles.
 
 Mungers are basically freeform Perl modules that transform andE<sol>or validate the input data passed to it.  Here's an example munger, straight
@@ -425,7 +430,8 @@ This munger does two (useless) things: change the name of the C<<< item >>> vari
 could just as easily do anything Perl can do to transform and validate the data.
 
 All mungers are called by their class (ie: C<<< TestMunger->munge >>>), so all of them should have a package name.  They should also return either
-C<<< undef >>> (as a rejection) or the variable list (as a hashref).
+C<<< undef >>> (as a rejection) or the variable list (as a hashref).  If the input ends up with multiple alerts, a munger can also pass an arrayref
+(of hashrefs), and they will be sent to the outputs individually.
 
 A munger could also become the B<primary> piece for input transformationE<sol>validation by not specifying a Template option.
 
@@ -433,10 +439,46 @@ Mungers are also passed the L<TemplateGrp|Transform::Alert::TemplateGrp> object.
 
     $tmpl_grp->log->debug("Munger didn't like Message Body");
 
+=head2 Variable Passing
+
+If you're still confused on the variable passing, look at it this way:
+
+    Input ──┬── $text ───── InTemplate ───── t => { %+ } ──┬── Munger ───── { ??? } ───── Out...
+            └── $hash ────────────────────── p => $hash  ──┘
+ 
+    Input ──┬── $text ────────────────────── t => {    } ──┬── Munger ───── { ??? } ───── Out...
+            └── $hash ────────────────────── p => $hash  ──┘
+ 
+    Input ──┬── $text ───── InTemplate ───── t => { %+ } ──┬───────────────────────────── Out...
+            └── $hash ────────────────────── p => $hash  ──┘
+ 
+    Input ──┬── $text ────────────────────── t => {    } ──┬── Munger ───── [ { ??? }, ── Out...
+            └── $hash ────────────────────── p => $hash  ──┘                  { ??? }, ── Out...
+                                                                              { ??? } ] ─ Out...
+ 
+    ...OutTemplate ───── $str ───── Output
+
 =head1 CAVEATS
 
+=over
+
+=item *
+
 This doesn't work on Windows.  Blame L<Proc::ProcessTable>.  Or rather, L<this bug|https://rt.cpan.org/Ticket/Display.html?id=75931>.
 
+=back
+
+=over
+
+=item *
+
+One would consider this a grand feat of over-engineering, which doesn't apply to every single protocol cleanly.  For example,
+
+=back
+
+   email input templates alone probably shouldn't be used, as header order might change, and the SNMP I/O doesn't translate to text
+   very well.  YMMV.
+
 =head1 TODO
 
 =over
@@ -449,8 +491,8 @@ Moar IE<sol>O:
 
     Inputs            Outputs
     ------            -------
-    HTTP::Atom        
-    HTTP::RSS         
+    HTTP::Atom
+    HTTP::RSS
     File::CSV         File::CSV
     File::Text        File::Text
                       IRC
@@ -506,7 +548,7 @@ Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Brendan Byrd.
+This software is Copyright (c) 2013 by Brendan Byrd.
 
 This is free software, licensed under:
 
