@@ -1,11 +1,11 @@
 package Transform::Alert::Input::POP3;
 
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '1.00'; # VERSION
 # ABSTRACT: Transform alerts from POP3 messages
 
 use sanity;
 use Moo;
-use MooX::Types::MooseLike::Base qw(Str Int ArrayRef HashRef InstanceOf);
+use MooX::Types::MooseLike::Base qw(Str Int ArrayRef HashRef InstanceOf Maybe);
 
 use Net::POP3;
 use Email::MIME;
@@ -27,7 +27,15 @@ has password => (
 
 has _conn => (
    is        => 'rw',
-   isa       => InstanceOf['Net::POP3'],
+   isa       => Maybe[InstanceOf['Net::POP3']],
+   lazy      => 1,
+   default   => sub {
+      my $self = shift;
+      Net::POP3->new( %{$self->connopts} ) || do {
+         $self->log->error('POP3 New failed: '.$@);
+         return;
+      };
+   },
    predicate => 1,
    clearer   => 1,
 );
@@ -50,28 +58,26 @@ around BUILDARGS => sub {
    foreach my $keyword (qw{ Host ResvPort Timeout Debug }) {
       $hash->{connopts}{$keyword} = delete $hash->{connopts}{lc $keyword} if (exists $hash->{connopts}{lc $keyword});
    }
-   
+
    $orig->($self, $hash);
 };
 
 sub open {
    my $self = shift;
-   my $pop  = Net::POP3->new( %{$self->connopts} ) || do {
-      $self->log->error('POP3 New failed: '.$@);
-      return;
-   };
-   $self->_conn($pop);
-   
+   my $pop  = $self->_conn ||
+      # maybe+default+error still creates an undef attr, which would pass an 'exists' check on predicate
+      do { $self->_clear_conn; return; };
+
    unless ( $pop->login($self->username, $self->password) ) {
       $self->log->error('POP3 Login failed: '.$pop->message);
       return;
    }
-   
+
    my $msgnums = $pop->list;
    $self->_list([
       sort { $a <=> $b } keys %$msgnums
    ]);
-   
+
    return 1;
 }
 
@@ -84,14 +90,14 @@ sub get {
    my $self = shift;
    my $num = shift @{$self->_list};
    my $pop = $self->_conn;
-   
+
    my $amsg = $pop->get($num);
    unless ($amsg) {
       $self->log->error('Error grabbing POP3 message #'.$num.': '.$pop->message);
       return;
    }
    $pop->delete($num);
-   
+
    my $msg = join '', @$amsg;
    $msg =~ s/\r//g;
    my $pmsg = Email::MIME->new($msg);
@@ -104,7 +110,7 @@ sub get {
       $pmsg->header_obj->header_pairs,
       BODY => $body,
    };
-   
+
    return (\$msg, $hash);
 }
 
@@ -177,11 +183,15 @@ Full text of the raw message, including headers.  All CRs are stripped.
        # decoded via Email::MIME->new($msg)
        # $pmsg->body_str, or body_str of the first text/plain part (if it croaks), or $pmsg->body_raw
        # (all \r are stripped)
-       BODY => $str,  
+       BODY => $str,
     }
 
 =head1 CAVEATS
 
+Special care should be made when using input templates on raw email messages.  For one, header order may change, which is difficult to
+manage with REs.  For another, the message is probably MIME-encoded and would contain 80-character splits.  Use of Mungers here is B<highly>
+recommended.
+
 All messages are deleted from the system, whether it was matched or not.  If you need to save your messages, you should consider using
 L<IMAP|Transform::Alert::Input::IMAP>.
 
@@ -202,7 +212,7 @@ Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Brendan Byrd.
+This software is Copyright (c) 2013 by Brendan Byrd.
 
 This is free software, licensed under:
 
