@@ -1,11 +1,11 @@
 package Transform::Alert::Output::SNMP;
 
-our $VERSION = '0.95'; # VERSION
+our $VERSION = '1.00'; # VERSION
 # ABSTRACT: Transform alerts to SNMP traps (base class)
 
 use sanity;
 use Moo;
-use MooX::Types::MooseLike::Base qw(InstanceOf);
+use MooX::Types::MooseLike::Base qw(InstanceOf Maybe);
 
 use Net::SNMP;
 
@@ -13,12 +13,12 @@ with 'Transform::Alert::Output';
 
 has _session => (
    is        => 'rw',
-   isa       => InstanceOf['Net::SNMP'],
+   isa       => Maybe[InstanceOf['Net::SNMP']],
    lazy      => 1,
    default   => sub {
       my $self = shift;
       my ($session, $err) = Net::SNMP->session( %{$self->connopts} );
-      unless ($session) { 
+      unless ($session) {
          $self->log->error('SNMP Session failed: '.$err);
          return;
       }
@@ -28,7 +28,12 @@ has _session => (
    clearer   => 1,
 );
 
-sub open   { shift->_session; }
+sub open   {
+   my $self = shift;
+   $self->_session ||
+      # maybe+default+error still creates an undef attr, which would pass an 'exists' check on predicate
+      do { $self->_clear_session; return; };
+}
 sub opened { shift->_has_session; }
 sub send   { die "Dummy method send() called for Output::SNMPTrap!  This must be overloaded!"; }
 sub close  {
@@ -45,9 +50,9 @@ sub close  {
 sub _translate_msg {
    my ($self, $msg) = @_;
    $msg = $$msg if (ref $msg eq 'SCALAR');
-   
+
    $msg =~ s/^\s+|\s+$//g;  # remove leading/trailing ws
-   
+
    return [ map { split /\s+/, $_, 3 } split /[\r\n]+/, $msg ];
 }
 
@@ -104,7 +109,7 @@ Brendan Byrd <BBYRD@CPAN.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Brendan Byrd.
+This software is Copyright (c) 2013 by Brendan Byrd.
 
 This is free software, licensed under:
 
